import Options from "./elm-view-options";
export default class ElmViewEngine {
    private _options;
    static readonly GENERATION_DIR_BASE_PATH: string;
    private static readonly TEMPLATE_PATH;
    private static readonly OUTPUT_JS_FILENAME;
    private worker;
    private getViewRequests;
    private requestsRecyclingPool;
    private lastCompileError?;
    private isUpdated;
    private watcher;
    private debug;
    readonly options: Options;
    constructor(_options?: Options);
    /**
     * Compiles the views in the views folder and generates a javascript module
     * Outputted in the Options.compilePath folder (defaults to views folder).
     */
    compile(): Promise<string>;
    /**
     * Returns true if compilation is needed before calling #getView().
     */
    needsCompilation(): Promise<boolean>;
    /**
     * Produce the view requested if it is in the views folder.
     * @param name name of the requested view. MUST be defined!
     * @param context context object of the view. Must have properties matching the elm deserializer in the elm view.
     */
    getView(name?: string | null, context?: any): Promise<string>;
    private watchCompiledViews();
    private cleanGenerated();
    private readViewsDir();
    private readTemplate();
    private compileAndOutputTemplate(files, templateContent);
    private getModuleName(file);
    private ensureTempDirStructure();
    private copyDependenciesFromProject(generatedPath);
    private saveMainElmFile(generatedProjectPath, elmCode);
    private compileElmModule(options, modulePath);
    private outputElmJsModule(elmCode);
    private outputElmPackageConfig(outputDir, config);
    private loadElmPackageConfig(elmRoot);
    private createRequestHandler(resolve, reject, port);
}
