"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const elm_view_engine_1 = require("./elm-view-engine");
exports.ElmViewEngine = elm_view_engine_1.default;
const elm_view_options_1 = require("./elm-view-options");
exports.Options = elm_view_options_1.default;
let currentOptions;
let engine;
let isCompiling = false;
function configure(options) {
    return __awaiter(this, void 0, void 0, function* () {
        if (isCompiling) {
            return Promise.reject(new Error("There is already a compilation in progress"));
        }
        isCompiling = true;
        const configureExpressApp = () => {
            if (engine.options.expressApp &&
                typeof engine.options.expressApp.set === "function" &&
                typeof engine.options.expressApp.engine === "function") {
                const app = engine.options.expressApp;
                app
                    .set("views", engine.options.viewsDirPath)
                    .set("view engine", "elm")
                    .engine("elm", __express);
            }
        };
        if (options instanceof elm_view_engine_1.default) {
            engine = options;
            currentOptions = engine.options;
        }
        else if (options instanceof elm_view_options_1.default) {
            currentOptions = options;
            engine = new elm_view_engine_1.default(currentOptions);
        }
        else {
            engine = new elm_view_engine_1.default();
            currentOptions = engine.options;
        }
        const needsCompilation = yield engine.needsCompilation();
        if (!needsCompilation && !engine.options.forceCompilation) {
            isCompiling = false;
            configureExpressApp();
            return engine;
        }
        configureExpressApp();
        try {
            yield engine.compile();
        }
        catch (error) {
            throw error;
        }
        finally {
            isCompiling = false;
        }
        return engine;
    });
}
exports.configure = configure;
function __express(filePath, options, callback) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!engine) {
            throw new Error("#configure must be called before calling #__express");
        }
        const viewName = path.parse(filePath).name;
        try {
            const html = yield engine.getView(viewName, options);
            if (callback) {
                callback(null, html);
            }
            return html;
        }
        catch (err) {
            if (callback) {
                callback(err);
            }
            throw err;
        }
    });
}
exports.__express = __express;
function reset() {
    if (isCompiling || !currentOptions) {
        return false;
    }
    engine = new elm_view_engine_1.default(currentOptions);
    return true;
}
exports.reset = reset;
//# sourceMappingURL=index.js.map